爱乐之城 (豆瓣)
Description: 爱乐之城电影简介和剧情介绍,爱乐之城影评、图片、预告片、影讯、论坛、在线购票
Keywords: 爱乐之城,La La Land,爱乐之城影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.232豆瓣电影Top250

# 爱乐之城 La La Land (2016)

导演: 达米恩·查泽雷
编剧: 达米恩·查泽雷
主演: 瑞恩·高斯林 / 艾玛·斯通 / 约翰·传奇 / 罗丝玛丽·德薇特 / 芬·维特洛克 / 杰西卡·罗德 / 水野索诺娅 / 考莉·埃尔南德斯 / J·K·西蒙斯 / 汤姆·艾弗瑞特·斯科特 / 米根·费伊 / 达蒙·冈普顿 / 贾森·福克斯 / 乔什·平茨 / 艾米·科恩 / 特里·沃尔特斯 / 汤姆·谢尔顿 / 信达·亚当斯 / 克劳丁·克劳迪奥 / D·A·瓦拉赫 / 特雷弗·里斯奥尔 / 奥莉维亚·汉密尔顿 / 安娜·查泽雷 / 马里乌斯·代·弗里斯 / 妮科尔·库隆 / 迈尔斯·安德森 / 约翰·辛德曼 / 瓦拉里·雷·米勒 / 基夫·范登·霍伊维尔 / 佐伊·霍尔 / 登普西·帕皮恩 / 辛德拉·车
类型: 剧情 / 爱情 / 歌舞
制片国家/地区: 美国
语言: 英语
上映日期: 2017-02-14(中国大陆) / 2016-08-31(威尼斯电影节) / 2016-12-25(美国)
片长: 128分钟
又名: 星声梦里人(港) / 乐来越爱你(台) / 爵士情缘 / 啦啦之地
IMDb: tt3783958
豆瓣评分
引用
8.4
836245人评价
5星
43.1%
4星
37.9%
3星
16.1%
2星
2.2%
1星
0.6%
好于 97% 爱情片
好于 96% 歌舞片
想看 看过
评价:
推荐

## 爱乐之城的剧情简介 · · · · · ·

米娅（艾玛·斯通 Emma Stone 饰）渴望成为一名演员，但至今她仍旧只是片场咖啡厅里的一名平凡的咖啡师，尽管不停的参加着大大小小的试镜，但米娅收获的只有失败。某日，在一场派对之中，米娅邂逅了名为塞巴斯汀（瑞恩·高斯林 Ryan Gosling 饰）的男子，起初两人之间产生了小小的矛盾，但很快，米娅便被塞巴斯汀身上闪耀的才华以及他对爵士乐的纯粹追求所吸引，最终两人走到了一起。
在塞巴斯汀的鼓励下，米娅辞掉了咖啡厅的工作，专心为自己写起了剧本，与此同时，塞巴斯汀为了获得一份稳定的收入，加入了一支流行爵士乐队，开始演奏自己并不喜欢的现代爵士乐，没想到一炮而红。随着时间的推移，努力追求梦想的两人，彼此之间的距离却越来越远，在理想和感情之间，他们必须做出选择。 ©豆瓣

## 爱乐之城的演职员 · · · · · · ( 全部 56 )

- 达米恩·查泽雷 导演
- 瑞恩·高斯林 饰 塞巴斯汀 Sebastian
- 艾玛·斯通 饰 米娅 Mia
- 约翰·传奇 饰 基斯 Keith
- 罗丝玛丽·德薇特 饰 劳拉 Laura Wilder
- 芬·维特洛克 饰 格雷格 Greg Earnest

## 爱乐之城的视频和图片 · · · · · · ( 预告片46 | 添加视频评论 | 图片2088 · 添加 )

## 爱乐之城的获奖情况 · · · · · · ( 全部 )

- 第89届奥斯卡金像奖
- 最佳影片(提名)
- 约旦·霍洛维茨 / 弗雷德·伯格 / 马克·普拉特

- 第73届威尼斯电影节
- 主竞赛单元 金狮奖 (提名)
- 达米恩·查泽雷

- 第74届金球奖
- 电影类 最佳音乐/喜剧片

## 喜欢这部电影的人也喜欢 · · · · · ·

  爱在黎明破晓前

  罗马假日

  重庆森林

  恋恋笔记本

  花束般的恋爱

  花样年华

  泰坦尼克号

  再次出发之纽约遇见你

  傲慢与偏见

  真爱至上

我要写短评

## 爱乐之城的短评 · · · · · · ( 全部 275316 条 )

热门 / 最新 / 好友

### 6344 有用 奇奇弟弟 看过 2016-12-13 05:48:21

不过是一个很俗套的故事。复古还真的一点都没看出来，把洛杉矶拍得像instagram旅游号，高司令从头到尾一副刚睡醒的样子，和那些经典音乐剧电影比起来缺少太多质感。现在连卖给少女的春药都是那么的廉价。

### 5699 有用 亵渎电影 看过 2016-12-18 22:37:42

年度十佳！最后在情字上找到了一个引人共鸣的点，人生就是一个不断追逐梦想的旅程，在某个时间点上，一个人遇到一个人，他们一起成长，相互鼓励，有美好，有痛苦，有成长，有遗憾，这就是人生。导演非常成熟老道，不仅有野心，也有足够的才华，歌舞元素几乎就是整个歌舞片的发展史，适合迷影爱好者。

### 3029 有用 Mo 看过 2016-12-26 10:47:13

前一个半小时都在出戏 从5 years later之后才有点感觉 觉得想找布达佩斯大饭店的画风失败 想找伍迪艾伦的文艺失败 想找宝莱坞电影一言不合就歌舞失败 唯独成功是最后的平行世界桥段 算是能赚观众一点同理心

### 19676 有用 桃桃林林 看过 2016-12-18 20:05:12

最后两人一吻上，眼泪就完全止不住，最后一直是痛哭。那段蒙太奇展示的就是电影的魔力啊！生活给不了的，电影可以给你，是那么浪漫、那么神奇的情感再现，最佳的电影造梦时刻。而至于理想、爱情、迷影、歌舞片、怀旧等等其他元素和小技巧反而可以放在之后了。最感慨的仍是电影的魅力，做一场电影梦吧！

### 21598 有用 C.W 看过 2016-12-16 16:48:26

这部电影有多好呢？想象这样一个场景：二十年后的一个傍晚，你开着车(或者车载着你)在回家的路上，突然扬声器里开始放起这首电影里的旋律，听到第一个音符的一瞬间，所有的情绪全都涌上来，就好像二十年前的那个夜晚你第一次听到它们的时候那样。

> 更多短评 275316条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 爱乐之城的影评 · · · · · · ( 全部 8245 条 )

热门 / 最新 / 好友
邵氏学府 2016-12-30 14:38:26

## Phd phd land

这篇影评可能有剧透

男主角高司令是刚拿到教职的小讲师，他的梦想是建立一个小研究所，保存日渐衰亡的定性研究方法，恢复摩尔和斯考切波的昔日荣光。不过因为发不出文章带不到学生也拿不到研究资助。在做完一场全部观众打瞌睡的历史社会学presentation之后，连导师也让他滚蛋。可是presentation的... (展开)
5959 858 315回应 收起
Prufrock的情歌 2016-12-26 10:49:26

## 再见 天使之城

【其实看完电影，翻了影评人和身边朋友的评价，我一直生活在深深的自我怀疑里。为什么我会这么不喜欢它呢？如果去看的那天我和同去的朋友不是恰好都沉浸在考试季的焦虑里，结果会不会不一样？如果我不是在洛杉矶这座城市身上投射了太多的个人情感，我是不是就能更平和地看待它... (展开)
5064 1081 728回应 收起
街道办爱豆 2016-12-11 13:01:16

## 在纯粹的梦想面前，任何善意的非善意的揣测和同情都自惭形秽

现已不接受任何转载，望谅。谢谢。 ——————————————————— 影片结束，放映室灯光亮起，我坐在自己的座位上久久没有起身。 La La Land，是我近几年看过的、最打动我的片子。介于别的影评已经从不同角度（Chazelle独特的歌舞片风格、对好莱坞歌舞片黄金时代的致... (展开)
5321 339 313回应 收起
大奇特(Grinch) 2017-02-14 08:33:38

## 知道《爱乐之城》这89个梗，你就能了解大半个歌舞片史

这篇影评可能有剧透

歌舞片已经不像它们在上世纪30至60年代那样普遍了，虽然每隔一两年我们还是能看到几部，但这些屈指可数的歌舞片大都在原地踏步，已无法恢复鼎盛时期的天真与烂漫。此番《爱乐之城》能够脱颖而出，正是由于它返璞归真地采用好莱坞传统歌舞片的形式及法国导演雅克·德米(Jacques ... (展开)
5072 132 392回应 收起
小墨MO 2017-01-11 08:38:38

## 如何优雅地欣赏电影《爱乐之城》？

这篇影评可能有剧透

温馨提示：下文为2月6日修改版本，调整了结构、添加了图片、减少了剧透：） Enjoy~ 讲真，看《爱乐之城》的那天非常曲折。 伦敦试映当晚， 我和@阿猴HOSEA 沐浴更衣， 正准备盛装前往。 手机突然嗡嗡响， 邮件提醒说： 伦敦地铁又罢工了！！！ 于是收起高跟鞋， 踩起运动鞋， ... (展开)
5281 204 315回应 收起
王微辣 2017-01-11 13:34:42

## 吃不进的少女春药

这篇影评可能有剧透

对不住大家，这部能在豆瓣能刷到9.1分的《La La Land》，我就是要唱唱反调。国内的朋友也别急，3月就会上映了。这里还有个海量剧透预警，如果你仍然期待花两个小时做一场梦，这篇也先别看了。 去看的原因很简单，身边的少女朋友强行喂我吃了一颗安利：此片关于梦想，关于错过，... (展开)
2190 580 413回应 收起
谢飞导演 2017-02-23 00:13:59

## 爱乐之城观后

年纪大了，已经多年不去影院看片。今天破例到离家最近的五棵松成龙耀莱影城的杜比影厅，去看了这部呼声很高的，真正宽银幕、环绕立体声的电影《爱乐之城》！ 我给它打四颗星。 三颗星给视听制作，给歌舞片样式的完成度。一个85年出生的年轻导演，对百年电影传统，对好莱坞歌舞... (展开)
703 61 92回应 收起
曼仔 2016-12-20 12:15:45

## 最是重逢一霎那，看到我们错过的人生，具体而微

这篇影评可能有剧透

刚刚看完La La Land（中译名为“爱乐之城”），真是年末的小惊喜。电影的情节并不复杂，探讨的话题也似曾相识，从思想层面上并没有让人耳目一新，但是在情感的处理上，却非常动人。 从爱情角度讲，其实是一个典型的好莱坞式boy-meets-girl的故事类型。女主角Mia （Emma Stone... (展开)
1680 31 89回应 收起
阿拉丁 2017-02-16 18:22:35

## 编剧太坏了，给女主埋了瓶绿茶你们都没看出来？

想不通，这样一部埋汰文艺青年尤其是文艺女青年的电影，还真有人看得稀里哗啦的。请问各位妹纸，你们真的看懂了么？对比男主角剧中的男主塞巴斯蒂安，剧中很多的细节都透露出这俩人根本不是一路人，尤其女主米娅，就是个大写的绿茶啊！ 1.开场，男女主角在拥堵路上的偶遇。男... (展开)
2166 645 423回应 收起
礼士路西岛秀俊 2017-02-14 18:47:55

## 爱乐之屯（又名：LA LA VILLAGE）

这篇影评可能有剧透

故事发生在当代的北京。 两个人的相聚，缘于梦想，缘于爱情，缘于命运。 石艾玛在南锣鼓巷的一家咖啡店打工。她二十出头，不漂亮，却颇有点儿特色。厚厚的嘴唇，大大的眼睛，直径14.2的美瞳闪烁着祖母绿光辉。她是家乡的时尚达人，拥有“铁岭小舒淇”的美誉。 石艾玛来自铁... (展开)
629 80 147回应 收起

> 更多影评 8245篇

添加新讨论

## 讨论区 · · · · · ·

刚刚才知道这个词 | 来自刀笔吏 |  | 2022-11-24 18:29:49
有人想要英文原版剧本嘛？ | 来自佛罗伦萨综合症 |  | 2022-11-23 13:40:54
电影的评价为何会两级化？ | 来自MARCO瞬息云 | 81 回应 | 2022-11-21 11:56:41
La La Land如果直译是什么 | 来自松鹤 | 30 回应 | 2022-11-20 20:52:54
女主在给谁打电话？ | 来自Drogoo | 8 回应 | 2022-11-20 19:25:41

> 去这部影片的讨论区（全部631条）

## 关于《爱乐之城》的问题 · · · · · · ( 全部118个 )

- lala land三月大陆会引进，作为一名有素质的单身狗去电影院看合适吗？ 58人回答
- 片名叫la la land是因为在LA拍摄的，取其音？还是另有隐喻？ 19人回答

> 全部118个问题

## 在哪儿看这部电影 · · · · · ·

- 优酷视频 VIP免费观看
- 西瓜视频 VIP免费观看
- 哔哩哔哩 VIP免费观看

## 本片原声正在播放 · · · · · ·

去豆瓣音乐收听

## 以下片单推荐 · · · · · · ( 全部 )

- 【内牛满面】 (影志)
- {北美电影票房总排行} (荔枝超人)
- 剧情扣人、故事性强、不闷的好电影 (影志)
- ★豆瓣高分电影榜★ （中）8.5-8.3分 (影志)
- 豆瓣电影【口碑榜】2022-06-13 更新 (影志)

## 谁在看这部电影 · · · · · ·

- stellar
  2分钟前 想看
- 柚子
  3分钟前 看过
- # 北平遗址
  4分钟前 看过

1367687人看过 / 253090人想看

订阅爱乐之城的评论:
feed: rss 2.0